%
% function [sections]=sectioner(cruise_num)
%
% This makes creating the 98 section files easier
% for example sectioner('01')
% be sure to use the quotes and a two digit number
%
% You shouldn't need this, but I've included it as a tool
%
% This requires casco_coast, or remove that portion and
% do your best to recognize the cruise transects by lat/lon
%
%


function [sections]=sectioner(cruise_num)

if nargin~=1
help sectioner
return
end

if ischar(cruise_num)~=1
disp('Type cruise_num as a character, jerky!')
help stationer
return
end

matty=['98cb' cruise_num];
load(matty);

% Create the cell arrays we'll be filling
sections.sect={'A','B','C','D','E','F'};
sections.stanum={[],[],[],[],[],[]};

% default projection is mercator
map_figure = gcf;
m_proj ( 'mercator' );

figure(str2int(cruise_num))
bl = line ( 'xdata', cruise.lon, ...
            'ydata', cruise.lat, ...
            'zdata', zeros(size(cruise.lon)), ...
            'LineStyle', 'none', ...
            'Marker', '.', ...
            'MarkerSize', 45, ...
            'Color', 'k', ...
            'Tag', 'black outline cast locations' );

wl = line ( 'xdata', cruise.lon, ...
            'ydata', cruise.lat, ...
            'zdata', ones(size(cruise.lat)), ...
            'LineStyle', 'none', ...
            'Marker', '.', ...
            'MarkerSize', 35, ...
            'Color', 'w', ...
            'Tag', 'white center cast locations' );
stanum_labels = text ( cruise.lon, cruise.lat, 2*ones(size(cruise.lat)), num2str(cruise.stanum(:)), ...
            'Fontsize', 6, ...
            'Color', [0.0 0.0 0.0], ...
            'HorizontalAlignment', 'center', ...
            'Tag', 'station number labels' );

load casco_coast
line(coast(:,1),coast(:,2));

dasp(43);
% now get the indices of the stations to make sections out of

for number_of_sections=1:6
	disp([sections.sect{number_of_sections} ' line'])
	sections.stanum{number_of_sections} = input ( 'enter vector for station numbers:  ' );
	station_numbers=sections.stanum{number_of_sections};

    %
    % plot the line connecting the indicated stations
    sect_line = line ( 'xdata', cruise.lon(station_numbers), ...
                       'ydata', cruise.lat(station_numbers), ...
                       'zdata', -1*ones(size(station_numbers)), ...
                       'color', 'k', ...
                       'Tag', 'section line' );



end

%define base_x and base_y!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
base_x=[-70.1575;-69.4726];
base_y=[43.5010;43.7553];

[base_mx, base_my] = m_ll2xy ( base_x, base_y );


baseline = line ( 'XData', base_x, ...
                  'YData', base_y, ...
                  'Color', 'r', ...
                  'LineWidth', 2, ...
                  'Tag', 'baseline' );

% now create the lateral_dist

for i=1:length(sections.stanum)

if ~isempty(sections.stanum{i})
inds = sections.stanum{i};
station_lon = cruise.lon(inds);
station_lat = cruise.lat(inds);
sections.lateral_dist{i} = lateral_distance ( station_lon, station_lat, base_x, base_y );
else sections.lateral_dist{i}=[];
end
end

cruise.sections=sections;
eval(['save ' matty ' cruise']);


