%
% function []=v_contour(sectract,contour_vector,clim_vector,[clabel_flag])
%
% EXAMPLE  v_contour(D_sal,[26:.5:32],[26 32],'off')
%
% This function draws a vertical profile of a given transect
% and variable which were specified in V_XTRACT
% sectract is the output structure from V_XTRACT
%
% VARIABLES
%
% contour_vector specifies the contouring, clim_vector the colorlimits
% set clabel_flag to 'off' if you don't want the contour labels
% clabel_flag must be the last argument and is optional
%
% If the contour_vector and/or the clim_vector are not specified they
% will be set automatically
%
% The colormap is set to gray, but feel free to get creative.
% 
% You lose the automatic setting of min and max X, but adds alot
% of flexibility.
%
%

function []=v_contour(sectract,varargin)
if nargin==0
help v_contour
return
end

% Make sense of the user's input
if length(varargin)==0
	noarguments=0;
elseif strcmp(varargin{length(varargin)},'off')==1
	clabel_flag=1;
	if length(varargin)==3
	contour_vector=varargin{1};
	clim_vector=varargin{2};
	elseif length(varargin)==2
	contour_vector=varargin{1};
	end
elseif length(varargin)==2
	contour_vector=varargin{1};
	clim_vector=varargin{2};
elseif length(varargin)==1
	contour_vector=varargin{1};
end


clf
sec_plot_figure = gcf;
%set( gcf,'Position',[165 304 1091 652]);

cmap = ((gray(100).*.75)+.25);
[r,c] = size(cmap);
%cmap = cmap(20:80,:);
colormap(cmap);

% flip the colormap if temperature is the variable
if strcmp(sectract.variable,'temp')==1
        colormap(flipud(cmap));
end

% do the contouring
if exist('clabel_flag')==1
	if exist('contour_vector')==1
	extcontour( sectract.x, sectract.y, sectract.v, contour_vector,...
    	'fill','color','black');
	else
	extcontour( sectract.x, sectract.y, sectract.v,...
    	'fill','color','black');
	end
else
	if exist('contour_vector')==1
	extcontour( sectract.x, sectract.y, sectract.v, contour_vector,...
    	'fill','label','color','black');
	else
	extcontour( sectract.x, sectract.y, sectract.v,...
    	'fill','label','color','black');
	end
end

hold off

% overlay the bottom
patch(sectract.bathy(:,1),sectract.bathy(:,2),[.76 .68 .54])

% label the stations

section_dist = sectract.section_dist;
    station_numbers = sectract.stanum;
    station_ids=sectract.staid;
cast_label=sprintf('#%2.2d',station_numbers);
cast_label=reshape(cast_label,3,length(cast_label)/3);
cast_label=cast_label.';
th = text (section_dist, 0*section_dist, cast_label, ...
                       'HorizontalAlignment', 'center', ...
                       'VerticalAlignment', 'Baseline', ...
                       'color', [0.2 0.2 0.2], ...
                       'FontSize', 10);
sh = text (section_dist, 0*section_dist+2, station_ids,...
                       'HorizontalAlignment', 'center', ...
                       'VerticalAlignment', 'Baseline', ...
                       'color', [0.2 0.2 0.2], ...
                       'FontSize', 10);

title ( sprintf ( '%s: %s', sectract.descript, sectract.variable ), ...
        'Tag', 'Section Plot Title' );

% Set some common properties
set ( gca, ...
        'Box', 'on', ...
	'Ylim', [-50 0], ...
	'Xlim', [min(sectract.x(:)) max(sectract.x(:))], ...
        'Layer', 'top', ...
        'Color', [1 1 1]);

if exist('clim_vector')==1
	set( gca,'Clim',clim_vector);
elseif exist('contour_vector')==1
	set( gca,'Clim',[min(contour_vector) max(contour_vector)]);
end	

%dolandscape

return
