%
% function []=v_pslice(sectract,clim_vector)
%
% EXAMPLE  v_pslice(D_sal,[26 32])
%
% This function draws a vertical profile of a given transect
% and variable which were specified in V_XTRACT
% in a pslice format.  pslice (and other stuff) is available at
%  http://crusty.er.usgs.gov/sea-mat/index-auto.html
%
% VARIABLES
%
%  clim_vector specifies the colorlimits (optional)
% sectract is the output structure from V_XTRACT
%
% The colormap is set to gray, but feel free to get creative.
% 
% You lose the automatic setting of min and max X, but adds alot
% of flexibility.
%
%

function []=v_pslice(sectract,clim_vector)
if nargin==0
help v_pslice
return
end

clf
sec_plot_figure = gcf;
%set( gcf,'Position',[165 304 1091 652]);

cmap = ((gray(100).*.75)+.25);
[r,c] = size(cmap);
%cmap = cmap(20:80,:);
colormap(cmap);

% flip the colormap if temperature is the variable
if strcmp(sectract.variable,'temp')==1
        colormap(flipud(cmap));
end

% do the psliceing
if exist('clim_vector')==1
pslice( sectract.x, sectract.y, sectract.v, clim_vector,sectract.variable);
else
pslice( sectract.x, sectract.y, sectract.v,sectract.variable);
 
end

hold off

% overlay the bottom
patch(sectract.bathy(:,1),sectract.bathy(:,2),[.76 .68 .54])

% label the stations

section_dist = sectract.section_dist;
    station_numbers = sectract.stanum;
    station_ids=sectract.staid;
cast_label=sprintf('#%2.2d',station_numbers);
cast_label=reshape(cast_label,3,length(cast_label)/3);
cast_label=cast_label.';
th = text (section_dist, 0*section_dist, cast_label, ...
                       'HorizontalAlignment', 'center', ...
                       'VerticalAlignment', 'Baseline', ...
                       'color', [0.2 0.2 0.2], ...
                       'FontSize', 10);
sh = text (section_dist, 0*section_dist+2, station_ids,...
                       'HorizontalAlignment', 'center', ...
                       'VerticalAlignment', 'Baseline', ...
                       'color', [0.2 0.2 0.2], ...
                       'FontSize', 10);

title ( sprintf ( '%s: %s', sectract.descript, sectract.variable ), ...
        'Tag', 'Section Plot Title' );

% Set some common properties
set ( gca, ...
        'Box', 'on', ...
	'Ylim', [-50 0], ...
	'Xlim', [min(sectract.x(:)) max(sectract.x(:))], ...
        'Layer', 'top', ...
        'Color', [1 1 1]);

%dolandscape

return
